from typing import Protocol, Any, Callable

class EventDispatcherInterface(Protocol):
    def dispatch(self, event_name: str, payload: Any) -> None: ...
    def add_listener(self, event_name: str, listener: Callable[[Any], None]) -> None: ...
